==> jc-1.4.0.tar.gz: java/beans/PropertyEditorManager.h <==
// public class java.beans.PropertyEditorManager

// class file dependencies
// @dep_class 71a594dafdc11fab java_beans_PropertyEditorManager
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_PropertyEditorManager_H_
#define _JC_java_beans_PropertyEditorManager_H_

// Forward structure declarations
struct _jc_java_beans_PropertyEditor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_beans_PropertyEditorManager$sub_refs	_jc_java_beans_PropertyEditorManager$sub_refs;
typedef struct _jc_java_beans_PropertyEditorManager$sub_nonrefs	_jc_java_beans_PropertyEditorManager$sub_nonrefs;
typedef struct _jc_java_beans_PropertyEditorManager$refs	_jc_java_beans_PropertyEditorManager$refs;
typedef struct _jc_java_beans_PropertyEditorManager$nonrefs	_jc_java_beans_PropertyEditorManager$nonrefs;
typedef struct _jc_java_beans_PropertyEditorManager$object	_jc_java_beans_PropertyEditorManager$object;

typedef struct _jc_java_beans_PropertyEditorManager$fields_struct	_jc_java_beans_PropertyEditorManager$fields_struct;
typedef const struct _jc_java_beans_PropertyEditorManager$vmethods	_jc_java_beans_PropertyEditorManager$vmethods;
typedef const struct _jc_java_beans_PropertyEditorManager$vtable	_jc_java_beans_PropertyEditorManager$vtable;
typedef const struct _jc_java_beans_PropertyEditorManager$vtype	_jc_java_beans_PropertyEditorManager$vtype;

// Class fields structure
struct _jc_java_beans_PropertyEditorManager$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24ColorEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24FontEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeBooleanEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeByteEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeDoubleEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeFloatEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeIntEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeLongEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeShortEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24StringEditor;
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Color;
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Font;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	_jc_object_array	*editorSearchPath;
	struct _jc_java_util_Hashtable$object	*editors;
};
extern _jc_java_beans_PropertyEditorManager$fields_struct _jc_java_beans_PropertyEditorManager$class_fields;

// Constructors
extern void _jc_java_beans_PropertyEditorManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_PropertyEditorManager$object *);

// Static methods
extern void _jc_java_beans_PropertyEditorManager$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_beans_PropertyEditorManager$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_object *_jc_java_beans_PropertyEditorManager$method$findEditor$ea4ad0abb600efcc(_jc_env *, struct _jc_java_lang_Class$object *);
extern _jc_object_array *_jc_java_beans_PropertyEditorManager$method$getEditorSearchPath$d942a6b8d575bb4f(_jc_env *);
extern void _jc_java_beans_PropertyEditorManager$method$registerEditor$540532845828fa5c(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *);
extern void _jc_java_beans_PropertyEditorManager$method$setEditorSearchPath$95355ae54551103f(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_java_beans_PropertyEditorManager$vmethods {
};

// Vtable
struct _jc_java_beans_PropertyEditorManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorManager$vmethods	java_beans_PropertyEditorManager;
};

// Vtype
struct _jc_java_beans_PropertyEditorManager$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyEditorManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyEditorManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyEditorManager$refs {
    _jc_java_beans_PropertyEditorManager$sub_refs	java_beans_PropertyEditorManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyEditorManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyEditorManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorManager$sub_nonrefs	java_beans_PropertyEditorManager;
};

// Object instance structure
struct _jc_java_beans_PropertyEditorManager$object {
	_jc_java_beans_PropertyEditorManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyEditorManager$vtype	*vtype;
	_jc_java_beans_PropertyEditorManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyEditorManager$vtype _jc_java_beans_PropertyEditorManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyEditorManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyEditorManager$class_object;

#endif	/* _JC_java_beans_PropertyEditorManager_H_ */

==> jc-1.4.6.tar.gz: java/beans/PropertyEditorManager.h <==
// public class java.beans.PropertyEditorManager

// class file dependencies
// @dep_class 71a594dafdc11fab java_beans_PropertyEditorManager
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_PropertyEditorManager_H_
#define _JC_java_beans_PropertyEditorManager_H_

// Forward structure declarations
struct _jc_java_beans_PropertyEditor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_beans_PropertyEditorManager$sub_refs	_jc_java_beans_PropertyEditorManager$sub_refs;
typedef struct _jc_java_beans_PropertyEditorManager$sub_nonrefs	_jc_java_beans_PropertyEditorManager$sub_nonrefs;
typedef struct _jc_java_beans_PropertyEditorManager$refs	_jc_java_beans_PropertyEditorManager$refs;
typedef struct _jc_java_beans_PropertyEditorManager$nonrefs	_jc_java_beans_PropertyEditorManager$nonrefs;
typedef struct _jc_java_beans_PropertyEditorManager$object	_jc_java_beans_PropertyEditorManager$object;

typedef struct _jc_java_beans_PropertyEditorManager$fields_struct	_jc_java_beans_PropertyEditorManager$fields_struct;
typedef const struct _jc_java_beans_PropertyEditorManager$vmethods	_jc_java_beans_PropertyEditorManager$vmethods;
typedef const struct _jc_java_beans_PropertyEditorManager$vtable	_jc_java_beans_PropertyEditorManager$vtable;
typedef const struct _jc_java_beans_PropertyEditorManager$vtype	_jc_java_beans_PropertyEditorManager$vtype;

// Class fields structure
struct _jc_java_beans_PropertyEditorManager$fields_struct {
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24ColorEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24FontEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeBooleanEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeByteEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeDoubleEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeFloatEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeIntEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeLongEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24NativeShortEditor;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24beans__24editors__24StringEditor;
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Color;
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Font;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24String;
	_jc_object_array	*editorSearchPath;
	struct _jc_java_util_Hashtable$object	*editors;
};
extern _jc_java_beans_PropertyEditorManager$fields_struct _jc_java_beans_PropertyEditorManager$class_fields;

// Constructors
extern void _jc_java_beans_PropertyEditorManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_PropertyEditorManager$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_beans_PropertyEditorManager$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_beans_PropertyEditorManager$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_PropertyEditorManager$method$findEditor$ea4ad0abb600efcc(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_beans_PropertyEditorManager$method$getEditorSearchPath$d942a6b8d575bb4f(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_beans_PropertyEditorManager$method$registerEditor$540532845828fa5c(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_PropertyEditorManager$method$setEditorSearchPath$95355ae54551103f(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_PropertyEditorManager$vmethods {
};

// Vtable
struct _jc_java_beans_PropertyEditorManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_PropertyEditorManager$vmethods	java_beans_PropertyEditorManager;
};

// Vtype
struct _jc_java_beans_PropertyEditorManager$vtype {
	_jc_type			type;
	_jc_java_beans_PropertyEditorManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_PropertyEditorManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_PropertyEditorManager$refs {
    _jc_java_beans_PropertyEditorManager$sub_refs	java_beans_PropertyEditorManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_PropertyEditorManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_PropertyEditorManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_PropertyEditorManager$sub_nonrefs	java_beans_PropertyEditorManager;
};

// Object instance structure
struct _jc_java_beans_PropertyEditorManager$object {
	_jc_java_beans_PropertyEditorManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_PropertyEditorManager$vtype	*vtype;
	_jc_java_beans_PropertyEditorManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_PropertyEditorManager$vtype _jc_java_beans_PropertyEditorManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_PropertyEditorManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_PropertyEditorManager$class_object;

#endif	/* _JC_java_beans_PropertyEditorManager_H_ */
